diff --git a/macosx/en.lproj/MainMenu.xib b/macosx/en.lproj/MainMenu.xib
index 94ff2a69e..700be4804 100644
--- a/macosx/en.lproj/MainMenu.xib
+++ b/macosx/en.lproj/MainMenu.xib
@@ -182,6 +182,7 @@
{{118, 5}, {279, 14}}
+
YES
@@ -4635,7 +4625,6 @@ AAAAAAAAAAAAAAAAA
-
@@ -4739,11 +4728,6 @@ AAAAAAAAAAAAAAAAA
-
- 2847
-
-
-
1683
@@ -6045,8 +6029,6 @@ AAAAAAAAAAAAAAAAA
com.apple.InterfaceBuilder.CocoaPlugin
{{558, 631}, {183, 33}}
- com.apple.InterfaceBuilder.CocoaPlugin
-
com.apple.InterfaceBuilder.CocoaPlugin
com.apple.InterfaceBuilder.CocoaPlugin
diff --git a/macosx/Controller.m b/macosx/Controller.m
index dbb696858..7ec112aeb 100644
--- a/macosx/Controller.m
+++ b/macosx/Controller.m
@@ -409,8 +409,8 @@ static void sleepCallback(void * controller, io_service_t y, natural_t messageTy
"Main window -> 1st bottom left button (action) tooltip")];
[fSpeedLimitButton setToolTip: NSLocalizedString(@"Speed Limit overrides the total bandwidth limits with its own limits.",
"Main window -> 2nd bottom left button (turtle) tooltip")];
- [fClearCompletedButton setToolTip: NSLocalizedString(@"Cleanup all transfers that have completed seeding.",
- "Main window -> 3rd bottom left button (cleanup) tooltip")];
+ [fClearCompletedButton setToolTip: NSLocalizedString(@"Remove all transfers that have completed seeding.",
+ "Main window -> 3rd bottom left button (remove all) tooltip")];
[fTableView registerForDraggedTypes: [NSArray arrayWithObject: TORRENT_TABLE_VIEW_DATA_TYPE]];
[fWindow registerForDraggedTypes: [NSArray arrayWithObjects: NSFilenamesPboardType, NSURLPboardType, nil]];
@@ -3601,7 +3601,7 @@ static void sleepCallback(void * controller, io_service_t y, natural_t messageTy
return canUseTable && [fTableView numberOfSelectedRows] > 0;
}
//cleanup completed transfers item
if (action == @selector(clearCompleted:))
{
for (Torrent * torrent in fTorrents)
@@ -3601,7 +3601,7 @@ static void sleepCallback(void * controller, io_service_t y, natural_t messageTy
return canUseTable && [fTableView numberOfSelectedRows] > 0;
}
- //cleanup completed transfers item
+ //remove all completed transfers item
if (action == @selector(clearCompleted:))
{